@@ -1,7 +1,5 @@
-/* aewm - An Exiguous Window Manager - vim:sw=4:ts=4:et
- *
- * Copyright 1998-2006 Decklin Foster <decklin@red-bean.com>. This
- * program is free software; please see LICENSE for details. */
+/* aewm - Copyright 1998-2006 Decklin Foster <decklin@red-bean.com>.
+ * This program is free software; please see LICENSE for details. */
 
 #include <stdlib.h>
 #include <string.h>
@@ -22,13 +20,14 @@ Atom net_client_stack;
 Atom net_active_window;
 Atom net_close_window;
 Atom net_cur_desk;
-Atom net_num_desktops;
+Atom net_num_desks;
 Atom net_wm_name;
-Atom net_wm_desktop;
+Atom net_wm_desk;
 Atom net_wm_state;
 Atom net_wm_state_shaded;
 Atom net_wm_state_mv;
 Atom net_wm_state_mh;
+Atom net_wm_state_fs;
 Atom net_wm_state_skipt;
 Atom net_wm_state_skipp;
 Atom net_wm_strut;
