@@ -1,7 +1,5 @@
-/* aewm - An Exiguous Window Manager - vim:sw=4:ts=4:et
- *
- * Copyright 1998-2006 Decklin Foster <decklin@red-bean.com>. This
- * program is free software; please see LICENSE for details. */
+/* aewm - Copyright 1998-2006 Decklin Foster <decklin@red-bean.com>.
+ * This program is free software; please see LICENSE for details. */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -36,3 +34,17 @@ int get_pointer(int *x, int *y)
     XQueryPointer(dpy, root, &real_root, &real_win, x, y, &wx, &wy, &mask);
     return mask;
 }
+
+int send_xmessage(Window w, Atom a, unsigned long x, unsigned long mask)
+{
+    XClientMessageEvent e;
+
+    e.type = ClientMessage;
+    e.window = w;
+    e.message_type = a;
+    e.format = 32;
+    e.data.l[0] = x;
+    e.data.l[1] = CurrentTime;
+
+    return XSendEvent(dpy, w, False, mask, (XEvent *)&e);
+}
