@@ -1,7 +1,5 @@
-/* aewm - An Exiguous Window Manager - vim:sw=4:ts=4:et
- *
- * Copyright 1998-2006 Decklin Foster <decklin@red-bean.com>. This
- * program is free software; please see LICENSE for details. */
+/* aewm - Copyright 1998-2006 Decklin Foster <decklin@red-bean.com>.
+ * This program is free software; please see LICENSE for details. */
 
 #ifndef AEWM_COMMON_H
 #define AEWM_COMMON_H
@@ -25,5 +23,6 @@ extern Window root;
 
 extern void fork_exec(char *);
 extern int get_pointer(int *, int *);
+extern int send_xmessage(Window, Atom, unsigned long, unsigned long);
 
 #endif /* AEWM_COMMON_H */
