@@ -1,7 +1,5 @@
-/* aewm - An Exiguous Window Manager - vim:sw=4:ts=4:et
- *
- * Copyright 1998-2006 Decklin Foster <decklin@red-bean.com>. This
- * program is free software; please see LICENSE for details. */
+/* aewm - Copyright 1998-2006 Decklin Foster <decklin@red-bean.com>.
+ * This program is free software; please see LICENSE for details. */
 
 #include <stdlib.h>
 #include <string.h>
@@ -50,15 +48,13 @@ char *get_rc_line(char *s, int size, FILE *stream)
 
 int get_token(char **src, char *dest)
 {
-    int quoted, nchars = 0;
+    int quoted = 0, nchars = 0;
 
     while (**src && isspace(**src)) (*src)++;
 
     if (**src == '"') {
         quoted = 1;
         (*src)++;
-    } else {
-        quoted = 0;
     }
 
     while (**src) {
@@ -68,7 +64,8 @@ int get_token(char **src, char *dest)
                 break;
             }
         } else {
-            if (isspace(**src)) break;
+            if (isspace(**src))
+                break;
         }
         if (**src == '\\') (*src)++;
         *dest++ = *(*src)++;
